# -*- coding: utf-8 -*-





from django.core.management.base import BaseCommand
from django.conf import settings
from django.db import transaction

from nagios_cache.models import NagiosServiceStatus, NagiosHostStatus, NagiosHostgroup, NagiosServicegroup
from nagios_cache.apps import DEFAULT_CONFIG


class Command(BaseCommand):

    TD_DAYS_DEFAULT = "(default)" if settings.NAGIOS_CACHE_CLEANCOMMAND_DAYS == DEFAULT_CONFIG['NAGIOS_CACHE_CLEANCOMMAND_DAYS'] else ""
    TD_HOURS_DEFAULT = "(default)" if settings.NAGIOS_CACHE_CLEANCOMMAND_HOURS == DEFAULT_CONFIG['NAGIOS_CACHE_CLEANCOMMAND_HOURS'] else ""

    help = """
    Clean Nagios cache in the database. You can adjust the age of the data in your settings.
    Currently the settings are defined via your settings or default values:

    NAGIOS_CACHE_CLEANCOMMAND_DAYS = %s %s
    NAGIOS_CACHE_CLEANCOMMAND_HOURS = %s %s

    """ % (settings.NAGIOS_CACHE_CLEANCOMMAND_DAYS, TD_DAYS_DEFAULT, settings.NAGIOS_CACHE_CLEANCOMMAND_HOURS, TD_HOURS_DEFAULT)

    def __init__(self, *args, **kwargs):
        super(Command, self).__init__(*args, **kwargs)

    @transaction.atomic
    def handle(self, *args, **options):
        NagiosHostStatus.clean_old(days=settings.NAGIOS_CACHE_CLEANCOMMAND_DAYS, hours=settings.NAGIOS_CACHE_CLEANCOMMAND_HOURS)
        NagiosHostgroup.clean_old(days=settings.NAGIOS_CACHE_CLEANCOMMAND_DAYS, hours=settings.NAGIOS_CACHE_CLEANCOMMAND_HOURS)
        NagiosServiceStatus.clean_old(days=settings.NAGIOS_CACHE_CLEANCOMMAND_DAYS, hours=settings.NAGIOS_CACHE_CLEANCOMMAND_HOURS)
        NagiosServicegroup.clean_old(days=settings.NAGIOS_CACHE_CLEANCOMMAND_DAYS, hours=settings.NAGIOS_CACHE_CLEANCOMMAND_HOURS)





from django.apps import AppConfig
from django.conf import settings

from django.core.checks import Error, Warning, register

DEFAULT_CONFIG = {
    'NAGIOS_CACHE_URL': None,
    'NAGIOS_CACHE_USER': None,
    'NAGIOS_CACHE_PASSWORD': None,
    'NAGIOS_CACHE_CLEANCOMMAND_DAYS': 1,
    'NAGIOS_CACHE_CLEANCOMMAND_HOURS': 0,
    'NAGIOS_CACHE_AUTOCLEAN': False,
    'NAGIOS_CACHE_AUTOCLEAN_DAYS': 1,
}


class NagiosCacheConfig(AppConfig):
    name = 'nagios_cache'

    def ready(self):
        for k, v in list(DEFAULT_CONFIG.items()):
            if not hasattr(settings, k):
                setattr(settings, k, v)


@register()
def config_validation(app_configs, **kwargs):
    errors = []
    if bool(settings.NAGIOS_CACHE_USER) ^ bool(settings.NAGIOS_CACHE_PASSWORD):
        errors.append(Warning('You should either define both or non of settings.NAGIOS_CACHE_USER and '
                              'settings.NAGIOS_CACHE_PASSWORD. Authentication at the Nagios/Icinga host '
                              'is disable. This is properly not what you want.',
                              id='nagios_cache.W001'))
    if not settings.NAGIOS_CACHE_URL:
        errors.append(Error('You must define settings.NAGIOS_CACHE_URL', id='nagios_cache.E001'))
    if settings.NAGIOS_CACHE_AUTOCLEAN and not type(settings.NAGIOS_CACHE_AUTOCLEAN_DAYS) == int:
        errors.append(Error('settings.NAGIOS_CACHE_AUTOCLEAN_DAYS must be an integer', id='nagios_cache.E002'))
    if settings.NAGIOS_CACHE_CLEANCOMMAND_DAYS == 0 and settings.NAGIOS_CACHE_CLEANCOMMAND_HOURS == 0:
        errors.append(Error('settings.NAGIOS_CACHE_CLEANCOMMAND_DAYS and NAGIOS_CACHE_CLEANCOMMAND_HOURS are 0. '
                            'Every nagios_clean command will wipe your database. This is properly not what you want.',
                            id='nagios_cache.E003'))
    return errors




# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2017-07-11 14:09
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nagios_cache', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='nagioshoststatus',
            name='status',
            field=models.SmallIntegerField(choices=[[1, 'OK'], [2, 'UP'], [3, 'DOWN'], [4, 'WARNING'], [5, 'CRITICAL'], [6, 'UNKNOWN'], [7, 'PENDING'], [8, 'UNREACHABLE']]),
        ),
        migrations.AlterField(
            model_name='nagiosservicestatus',
            name='status',
            field=models.SmallIntegerField(choices=[[1, 'OK'], [2, 'UP'], [3, 'DOWN'], [4, 'WARNING'], [5, 'CRITICAL'], [6, 'UNKNOWN'], [7, 'PENDING'], [8, 'UNREACHABLE']]),
        ),
    ]

